@@ -32,19 +32,15 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <gconf/gconf-client.h>
-#include <nautilus-burn.h>
-#include <libgnome/gnome-help.h>
-#include <libgnome/gnome-url.h>
-#include <libgnomeui/gnome-ui-init.h>
-#include <libgnomeui/gnome-authentication-manager.h>
+#include <brasero-medium-selection.h>
+#include <brasero-volume.h>
 #include <profiles/gnome-media-profiles.h>
 #include <gst/gst.h>
 
 #include "bacon-message-connection.h"
 #include "gconf-bridge.h"
 #include "sj-about.h"
-#include "sj-metadata.h"
-#include "sj-metadata-musicbrainz.h"
+#include "sj-metadata-getter.h"
 #include "sj-extractor.h"
 #include "sj-structures.h"
 #include "sj-error.h"
@@ -69,7 +65,7 @@ void on_disc_number_edit_changed(GtkEditable *widget, gpointer user_data);
 
 GladeXML *glade;
 
-SjMetadata *metadata;
+SjMetadataGetter *metadata;
 SjExtractor *extractor;
 
 GConfClient *gconf_client;
@@ -90,7 +86,7 @@ GtkWidget *current_message_area;
 
 const char *path_pattern, *file_pattern;
 GFile *base_uri;
-NautilusBurnDrive *drive = NULL;
+BraseroDrive *drive = NULL;
 gboolean strip_chars;
 gboolean eject_finished;
 gboolean open_finished;
@@ -219,7 +215,7 @@ void on_eject_activate (GtkMenuItem *item, gpointer user_data)
   /* first make sure we're not playing */
   stop_playback ();
 
-  nautilus_burn_drive_eject (drive);
+  brasero_drive_eject (drive, FALSE, NULL);
 }
 
 gboolean on_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
@@ -419,7 +415,7 @@ musicbrainz_submit_message_area_new (char *title, char *artist)
   message_area = gedit_message_area_new ();
 
   button = gedit_message_area_add_button (GEDIT_MESSAGE_AREA (message_area),
-                                          _("_Submit Album"),
+                                          _("S_ubmit Album"),
                                           GTK_RESPONSE_OK);
   gedit_message_area_add_button (GEDIT_MESSAGE_AREA (message_area),
                                  GTK_STOCK_CANCEL,
@@ -797,7 +793,7 @@ static void audio_volume_changed_cb (GConfClient *client, guint cnxn_id, GConfEn
 }
 
 static void
-metadata_cb (SjMetadata *m, GList *albums, GError *error)
+metadata_cb (SjMetadataGetter *m, GList *albums, GError *error)
 {
   gboolean realized = GTK_WIDGET_REALIZED (main_window);
 
@@ -825,6 +821,11 @@ metadata_cb (SjMetadata *m, GList *albums, GError *error)
     return;
   }
 
+  current_submit_url = sj_metadata_getter_get_submit_url (metadata);
+  if (current_submit_url) {
+    gtk_widget_set_sensitive (submit_menuitem, TRUE);
+  }
+
   /* Free old album details */
   if (current_album != NULL) {
     album_details_free (current_album);
@@ -859,19 +860,21 @@ metadata_cb (SjMetadata *m, GList *albums, GError *error)
 }
 
 static gboolean
-is_audio_cd (NautilusBurnDrive *drive)
+is_audio_cd (BraseroDrive *drive)
 {
-  NautilusBurnMediaType type;
-  gboolean audio;
-  if (drive == NULL) return FALSE;
-  type = nautilus_burn_drive_get_media_type_full (drive, NULL, NULL, NULL, &audio);
-  if (type == NAUTILUS_BURN_MEDIA_TYPE_ERROR) {
+  BraseroMedium *medium;
+  BraseroMedia type;
+
+  medium = brasero_drive_get_medium (drive);
+  if (medium == NULL) return FALSE;
+  type = brasero_medium_get_status (medium);
+  if (type == BRASERO_MEDIUM_UNSUPPORTED) {
     g_warning ("Error getting media type\n");
   }
-  if (type == NAUTILUS_BURN_MEDIA_TYPE_BUSY) {
+  if (type == BRASERO_MEDIUM_BUSY) {
     g_warning ("BUSY getting media type, should re-check\n");
   }
-  return audio;
+  return BRASERO_MEDIUM_IS (type, BRASERO_MEDIUM_HAS_AUDIO|BRASERO_MEDIUM_CD);
 }
 
 /**
@@ -914,12 +917,7 @@ static void reread_cd (gboolean ignore_no_media)
     return;
   }
 
-  current_submit_url = sj_metadata_get_submit_url (metadata);
-  if (current_submit_url) {
-    gtk_widget_set_sensitive (submit_menuitem, TRUE);
-  }
-
-  sj_metadata_list_albums (metadata, &error);
+  sj_metadata_getter_list_albums (metadata, &error);
 
   if (error && !(error->code == SJ_ERROR_CD_NO_MEDIA && ignore_no_media)) {
     GtkWidget *dialog;
@@ -946,19 +944,21 @@ static void reread_cd (gboolean ignore_no_media)
 }
 
 static void
-media_added_cb (NautilusBurnDrive *drive,
-                gpointer           data)
+media_added_cb (BraseroMediumMonitor	*drive,
+		BraseroMedium		*medium,
+                gpointer           	 data)
 {
   if (extracting == TRUE) {
     /* FIXME: recover? */
   }
 
-  sj_debug (DEBUG_CD, "Media added to device %s\n", nautilus_burn_drive_get_device (drive));
+  sj_debug (DEBUG_CD, "Media added to device %s\n", brasero_drive_get_device (brasero_medium_get_drive (medium)));
   reread_cd (TRUE);
 }
 
 static void
-media_removed_cb (NautilusBurnDrive *drive,
+media_removed_cb (BraseroMediumMonitor	*drive,
+		  BraseroMedium		*medium,
                   gpointer           data)
 {
   if (extracting == TRUE) {
@@ -968,7 +968,7 @@ media_removed_cb (NautilusBurnDrive *drive,
   /* first make sure we're not playing */
   stop_playback ();
 
-  sj_debug (DEBUG_CD, "Media removed from device %s\n", nautilus_burn_drive_get_device (drive));
+  sj_debug (DEBUG_CD, "Media removed from device %s\n", brasero_drive_get_device (brasero_medium_get_drive (medium)));
   stop_ui_hack ();
   update_ui_for_album (NULL);
 }
@@ -976,18 +976,18 @@ media_removed_cb (NautilusBurnDrive *drive,
 static void
 set_drive_from_device (const char *device)
 {
-  NautilusBurnDriveMonitor *monitor;
+  BraseroMediumMonitor *monitor;
 
   if (drive) {
-    nautilus_burn_drive_unref (drive);
+    g_object_unref (drive);
     drive = NULL;
   }
 
   if (! device)
     return;
 
-  monitor = nautilus_burn_get_drive_monitor ();
-  drive = nautilus_burn_drive_monitor_get_drive_for_device (monitor, device);
+  monitor = brasero_medium_monitor_get_default ();
+  drive = brasero_medium_monitor_get_drive (monitor, device);
   if (! drive) {
     GtkWidget *dialog;
     char *message;
@@ -1006,8 +1006,8 @@ set_drive_from_device (const char *device)
     return;
   }
 
-  g_signal_connect (drive, "media-added", G_CALLBACK (media_added_cb), NULL);
-  g_signal_connect (drive, "media-removed", G_CALLBACK (media_removed_cb), NULL);
+  g_signal_connect (monitor, "medium-added", G_CALLBACK (media_added_cb), NULL);
+  g_signal_connect (monitor, "medium-removed", G_CALLBACK (media_removed_cb), NULL);
 }
 
 static void
@@ -1046,34 +1046,33 @@ set_device (const char* device, gboolean ignore_no_media)
     set_drive_from_device (device);
   }
 
-  sj_metadata_set_cdrom (metadata, device);
+  sj_metadata_getter_set_cdrom (metadata, device);
   sj_extractor_set_device (extractor, device);
   
   if (drive != NULL) {
-    tray_opened = nautilus_burn_drive_door_is_open (drive);
+    tray_opened = brasero_drive_is_door_open (drive);
     if (tray_opened == FALSE) {
       reread_cd (ignore_no_media);
     }
-#if HAVE_NAUTILUS_BURN_DRIVE_CAN_EJECT
+
     // Enable/disable the eject options based on wether the drive supports ejection
-    gtk_widget_set_sensitive (eject, nautilus_burn_drive_can_eject (drive));
-#endif
+    gtk_widget_set_sensitive (eject, brasero_drive_can_eject (drive));
   }
 }
 
 gboolean cd_drive_exists (const char *device)
 {
-  NautilusBurnDriveMonitor *monitor;
-  NautilusBurnDrive *drive;
+  BraseroMediumMonitor *monitor;
+  BraseroDrive *drive;
   gboolean exists;
 
   if (device == NULL)
     return FALSE;
 
-  monitor = nautilus_burn_get_drive_monitor ();
-  drive = nautilus_burn_drive_monitor_get_drive_for_device (monitor, device);
+  monitor = brasero_medium_monitor_get_default ();
+  drive = brasero_medium_monitor_get_drive (monitor, device);
   exists = (drive != NULL);
-  nautilus_burn_drive_unref (drive);
+  g_object_unref (drive);
 
   return exists;
 }
@@ -1084,20 +1083,21 @@ prefs_get_default_device (void)
   static const char * default_device = NULL;
 
   if (default_device == NULL) {
-    NautilusBurnDriveMonitor *monitor;
-    NautilusBurnDrive *drive;
-    GList *drives;
+    BraseroMediumMonitor *monitor;
 
-    monitor = nautilus_burn_get_drive_monitor ();
-    drives = nautilus_burn_drive_monitor_get_drives (monitor);
+    BraseroDrive *drive;
+    GSList *drives;
+
+    monitor = brasero_medium_monitor_get_default ();
+    drives = brasero_medium_monitor_get_drives (monitor, BRASERO_DRIVE_TYPE_ALL);
     if (drives == NULL)
       return NULL;
 
     drive = drives->data;
-    default_device = nautilus_burn_drive_get_device (drive);
+    default_device = brasero_drive_get_device (drive);
 
-    g_list_foreach (drives, (GFunc)nautilus_burn_drive_unref, NULL);
-    g_list_free (drives);
+    g_slist_foreach (drives, (GFunc) g_object_unref, NULL);
+    g_slist_free (drives);
   }
   return default_device;
 }
@@ -1174,16 +1174,16 @@ static void
 http_proxy_setup (GConfClient *client)
 {
   if (!gconf_client_get_bool (client, GCONF_HTTP_PROXY_ENABLE, NULL)) {
-    sj_metadata_set_proxy (metadata, NULL);
+    sj_metadata_getter_set_proxy (metadata, NULL);
   } else {
     char *host;
     int port;
 
     host = gconf_client_get_string (client, GCONF_HTTP_PROXY, NULL);
-    sj_metadata_set_proxy (metadata, host);
+    sj_metadata_getter_set_proxy (metadata, host);
     g_free (host);
     port = gconf_client_get_int (client, GCONF_HTTP_PROXY_PORT, NULL);
-    sj_metadata_set_proxy_port (metadata, port);
+    sj_metadata_getter_set_proxy_port (metadata, port);
   }
 }
 
@@ -1233,7 +1233,7 @@ void on_submit_activate (GtkWidget *menuitem, gpointer user_data)
   GError *error = NULL;
 
   if (current_submit_url) {
-    if (!gnome_url_show (current_submit_url, &error)) {
+      if (!gtk_show_uri (NULL, current_submit_url, GDK_CURRENT_TIME, &error)) {
       GtkWidget *dialog;
 
       dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
@@ -1450,8 +1450,7 @@ void on_disc_number_edit_changed(GtkEditable *widget, gpointer user_data) {
 void on_contents_activate(GtkWidget *button, gpointer user_data) {
   GError *error = NULL;
 
-  /* If/when we drop libgnome, simply spawn the URI ghelp:sound-juicer. */
-  gnome_help_display ("sound-juicer", NULL, &error);
+  gtk_show_uri (NULL, "ghelp:sound-juicer", GDK_CURRENT_TIME, &error);
   if (error) {
     GtkWidget *dialog;
 
@@ -1509,12 +1508,12 @@ on_message_received (const char *message, gpointer user_data)
 static gboolean
 is_cd_duplication_available()
 {
-  // First check the nautilus-cd-burner tool is available in the path
-  gchar* nautilus_cd_burner = g_find_program_in_path ("nautilus-cd-burner");
-  if (nautilus_cd_burner == NULL) {
+  // First check the brasero tool is available in the path
+  gchar* brasero_cd_burner = g_find_program_in_path ("brasero");
+  if (brasero_cd_burner == NULL) {
     return FALSE;
   } 
-  g_free(nautilus_cd_burner);
+  g_free(brasero_cd_burner);
 
   // Second check the cdrdao tool is available in the path
   gchar* cdrdao = g_find_program_in_path ("cdrdao");
@@ -1524,18 +1523,27 @@ is_cd_duplication_available()
   g_free(cdrdao);  
 
   // Now check that there is at least one cd recorder available
-  GList                    *drives;
-  NautilusBurnDriveMonitor *monitor;
+  BraseroMediumMonitor     *monitor;
+  GSList		   *drives;
+  GSList		   *iter;
 
-  monitor = nautilus_burn_get_drive_monitor ();
-  drives = nautilus_burn_drive_monitor_get_recorder_drives (monitor);
+  monitor = brasero_medium_monitor_get_default ();
+  drives = brasero_medium_monitor_get_drives (monitor, BRASERO_DRIVE_TYPE_ALL);
 
-  if (drives == NULL) {
-     return FALSE;
+  for (iter = drives; iter; iter = iter->next) {
+    BraseroDrive *drive;
+
+    drive = iter->data;
+    if (brasero_drive_can_write (drive)) {
+      g_slist_foreach (drives, (GFunc) g_object_unref, NULL);
+      g_slist_free (drives);
+      return TRUE;
+    }
   }
 
-  g_list_free (drives);
-  return TRUE;
+  g_slist_foreach (drives, (GFunc) g_object_unref, NULL);
+  g_slist_free (drives);
+  return FALSE;
 }
 
 /**
@@ -1546,8 +1554,8 @@ void on_duplicate_activate (GtkWidget *button, gpointer user_data)
   GError *error = NULL;
   const gchar* device;
 
-  device = nautilus_burn_drive_get_device (drive);
-  if (!g_spawn_command_line_async (g_strconcat ("nautilus-cd-burner --source-device=", device, NULL), &error)) {
+  device = brasero_drive_get_device (drive);
+  if (!g_spawn_command_line_async (g_strconcat ("brasero -c ", device, NULL), &error)) {
       GtkWidget *dialog;
 
       dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
@@ -1579,7 +1587,6 @@ static void set_duplication(gboolean enabled)
 
 int main (int argc, char **argv)
 {
-  GnomeProgram *program;
   GError *error = NULL;
   GtkTreeSelection *selection;
   char *device = NULL, **uris = NULL;
@@ -1599,28 +1606,25 @@ int main (int argc, char **argv)
   textdomain (GETTEXT_PACKAGE);
 
   ctx = g_option_context_new (N_("- Extract music from your CDs"));
-  g_option_context_add_main_entries (ctx, entries, GETTEXT_PACKAGE);  
+  g_option_context_add_main_entries (ctx, entries, GETTEXT_PACKAGE);
   g_option_context_set_translation_domain(ctx, GETTEXT_PACKAGE);
+  g_option_context_add_group (ctx, gtk_get_option_group (TRUE));
   g_option_context_add_group (ctx, gst_init_get_option_group ());
+  g_option_context_add_group (ctx, brasero_media_get_option_group ());
   g_option_context_set_ignore_unknown_options (ctx, TRUE);
 
-  program = gnome_program_init ("sound-juicer",
-                      VERSION, LIBGNOMEUI_MODULE,
-                      argc, argv,
-                      GNOME_PROGRAM_STANDARD_PROPERTIES,
-                      GNOME_PARAM_GOPTION_CONTEXT, ctx,
-                      NULL);
+  g_option_context_parse (ctx, &argc, &argv, &error);
+  if (error != NULL) {
+      g_printerr ("Error parsing options: %s", error->message);
+      exit (1);
+  }
 
   g_set_application_name (_("Sound Juicer"));
 
-  gnome_authentication_manager_init ();
-
   sj_debug_init ();
 
   sj_stock_init ();
 
-  nautilus_burn_init ();
-
   gtk_window_set_default_icon_name ("sound-juicer");
   
   connection = bacon_message_connection_new ("sound-juicer");
@@ -1632,7 +1636,9 @@ int main (int argc, char **argv)
     bacon_message_connection_set_callback (connection, on_message_received, NULL);
   }
 
-  metadata = SJ_METADATA (sj_metadata_musicbrainz_new ());
+  brasero_media_library_start ();
+
+  metadata = sj_metadata_getter_new ();
   g_signal_connect (metadata, "metadata", G_CALLBACK (metadata_cb), NULL);
 
   gconf_client = gconf_client_get_default ();
@@ -1791,12 +1797,6 @@ int main (int argc, char **argv)
 
   sj_play_init ();
 
-#if HAVE_TAGLIB
-  /* See if the system supports id3mux, and if not register our own */
-  if (!gst_default_registry_check_feature_version ("id3mux", 0, 10, 0))
-    id3mux_register ();
-#endif
-
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (track_listview));
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 
@@ -1839,7 +1839,7 @@ int main (int argc, char **argv)
     return 0;
   }
 
-  // Set whether duplication of a cd is available using the nautilus-cd-burner tool
+  // Set whether duplication of a cd is available using the brasero tool
   gtk_widget_set_sensitive (duplicate, FALSE);
   duplication_enabled = is_cd_duplication_available();
 
@@ -1847,12 +1847,11 @@ int main (int argc, char **argv)
   gtk_widget_show (main_window);
   gtk_main ();
 
-  nautilus_burn_shutdown ();
-
   g_object_unref (base_uri);
   g_object_unref (metadata);
   g_object_unref (extractor);
   g_object_unref (gconf_client);
-  g_object_unref (program);
+  brasero_media_library_stop ();
+
   return 0;
 }
